@@ -5,7 +5,7 @@ import os.path
 import json
 import re
 
-__version__ = '1.0'
+__version__ = '1.0.3'
 
 def get_sexpr (pkg, code, i, canon=None):
     fraction_regex = re.compile("^[-+]?\\d+(/\\d+)?$")
@@ -414,7 +414,7 @@ class Acl2Kernel(Kernel):
                 if tree is None:
                     raise ValueError("Syntax error: :cmd or #-expr at end of file")
                 sexp = cmd + " " + sexp
-            converted += cmd + "\n\n"
+            converted += sexp + "\n\n"
         return converted
 
     def do_execute(self, code, silent, store_history=True,
@@ -442,6 +442,9 @@ class Acl2Kernel(Kernel):
         except ValueError as e:
             self.process_output("ACL2 Syntax Error: " + e.message)
             self.status = 0
+        except Exception as e:
+            self.process_output("Unhandled Exception: " + str(e))
+            self.status = 0
         except:
             self._bridge = None
             self.bridge
